

set -ex



pip check
jupyter nbextension list
jupyter nbextension list 1>nbextensions 2>&1
jupyter labextension list
jupyter labextension list 1>labextensions 2>&1
rg -ie "jupyter_bokeh/extension.*enabled" nbextensions
rg -ie "@bokeh/jupyter_bokeh.*OK.*jupyter_bokeh" labextensions
exit 0
