print("import: 'jupyter_bokeh'")
import jupyter_bokeh

print("import: 'jupyter_bokeh.nbextension'")
import jupyter_bokeh.nbextension

print("import: 'jupyter_bokeh.widgets'")
import jupyter_bokeh.widgets

